/*
** Module   : EmbeddedWebServer.java
** Abstract : embedded web server contract
**
** Copyright (c) 2013-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 MAG 20131218 Created initial version.
** 002 CA  20140214 Changed to allow explicit host and port.
** 003 MAG 20140217 Add shutdown server method.
** 004 GES 20150308 Moved to a more generic package location.
*/

package com.goldencode.p2j.ui.client.driver.web;

import com.goldencode.p2j.cfg.*;
import com.goldencode.p2j.main.*;

/**
 * Embedded web server API. 
 */
public interface EmbeddedWebServer
{
   /**
    * Startup the embedded web server using the application server's <code>KeyStore</code> to
    * build a suitable SSL context.
    * 
    * @param    keyStore
    *           The exported server KeyStore. 
    * @param    config
    *           Client configuration.
    * @param    port
    *           An explicit port to start the web server or 0 to let the OS assign one.
    * @param    host
    *           An explicit host to start the web server or <code>null</code> to use the server's
    *           host.
    */
   public String startupServer(ServerKeyStore keyStore, BootstrapConfig config, String host, int port);

   /**
    * Shutdown the embedded web server.
    */   
   public void shutdownServer();

   /**
    * Get the embedded web server's URI.
    * 
    * @return   A string representing the server's URI.
    */
   public String getServerURI();
}
